### Name: mnp
### Title: Fitting the Multinomial Probit Model via Markov chain Monte
###   Carlo
### Aliases: mnp MNP
### Keywords: models

### ** Examples

## load the detergent data
data(detergent)
## run the standard multinomial probit model with intercepts and the price
res1 <- mnp(choice ~ 1, choiceX = list(Surf=SurfPrice, Tide=TidePrice,
                                       Wisk=WiskPrice, EraPlus=EraPlusPrice,
                                       Solo=SoloPrice, All=AllPrice),
            cXnames = "price", data = detergent, n.draws = 500, burnin = 100,
            thin = 3, verbose = TRUE)
## summarize the results
summary(res1)
## calculate the predicted probabilities for the first 5 observations
predict(res1, newdata = detergent[1:3,], type="prob", verbose = TRUE)

## load the Japanese election data
data(japan)
## run the multinomial probit model with ordered preferences
res2 <- mnp(cbind(LDP, NFP, SKG, JCP) ~ sex + education + age, data = japan,
            verbose = TRUE)
## summarize the results
summary(res2)
## calculate the predicted probabilities for the 10th observation
predict(res2, newdata = japan[10,], type = "prob")



